@@ -104,7 +104,7 @@ KWalletEditor::KWalletEditor(QWidget *parent, const QString &name)
 
     box = new QVBoxLayout(_entryStack->widget(2));
     box->setContentsMargins(0, 0, 0, 0);
-    _mapEditorShowHide = new QCheckBox(i18n("&Show values"), _entryStack->widget(2));
+    _mapEditorShowHide = new QCheckBox(i18nc("@option:check", "&Show values"), _entryStack->widget(2));
     connect(_mapEditorShowHide, &QCheckBox::toggled, this, &KWalletEditor::showHideMapEditorValue);
     _mapEditor = new KWMapEditor(_currentMap, _entryStack->widget(2));
     box->addWidget(_mapEditorShowHide);
@@ -951,7 +951,13 @@ void KWalletEditor::showHideMapEditorValue(bool show)
     }
 }
 
-enum MergePlan { Prompt = 0, Always = 1, Never = 2, Yes = 3, No = 4 };
+enum MergePlan {
+    Prompt = 0,
+    Always = 1,
+    Never = 2,
+    Yes = 3,
+    No = 4
+};
 
 void KWalletEditor::importWallet()
 {
